import { useEffect } from 'react';
import { DEFAULT } from '../schema/config.js';
import { getProfileEvent, setProfileEvent } from '../lib/profile.js';
export function useProfile({ store, setError, update }) {
    const { client, isConnected, pubkey, profile, signer } = store;
    useEffect(() => {
        if (profile === undefined && pubkey !== undefined && isConnected) {
            update({ isLoading: true });
            void getProfile();
        }
    }, [pubkey, profile, isConnected]);
    async function getProfile() {
        let profile;
        if (typeof pubkey !== 'string') {
            setError('Pubkey is not defined!');
            return;
        }
        if (!isConnected || client === undefined) {
            setError('Client is not connected!');
            return;
        }
        try {
            const profile = await getProfileEvent(client, pubkey);
            if (profile !== undefined) {
                update({ profile });
            }
            else {
                update({ profile: DEFAULT.profile });
            }
        }
        catch (err) {
            setError(err);
        }
        finally {
            update({ isLoading: false });
        }
        return profile;
    }
    async function setProfile(updates) {
        const updated = { ...profile, ...updates };
        if (typeof pubkey !== 'string') {
            setError('Pubkey not defined!');
        }
        else if (typeof signer !== 'function') {
            setError('Signer not defined!');
        }
        else if (!isConnected || client === undefined) {
            setError('Client is not connected!');
        }
        else {
            setProfileEvent(client, updated, signer)
                .then(profile => { update({ profile }); })
                .catch(err => { setError(err); });
        }
    }
    return { getProfile, setProfile };
}
//# sourceMappingURL=useProfile.js.map